@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -28,6 +28,20 @@
 
 G_BEGIN_DECLS
 
+
+/**
+ * GMimePartEncodingType:
+ * @GMIME_PART_ENCODING_DEFAULT: Default transfer encoding.
+ * @GMIME_PART_ENCODING_7BIT: 7bit text transfer encoding.
+ * @GMIME_PART_ENCODING_8BIT: 8bit text transfer encoding.
+ * @GMIME_PART_ENCODING_BINARY: Binary transfer encoding.
+ * @GMIME_PART_ENCODING_BASE64: Base64 transfer encoding.
+ * @GMIME_PART_ENCODING_QUOTEDPRINTABLE: Quoted-printable transfer encoding.
+ * @GMIME_PART_ENCODING_UUENCODE: Uuencode transfer encoding.
+ * @GMIME_PART_NUM_ENCODINGS: The number of available transfer encoding enum values.
+ *
+ * A Content-Transfer-Encoding type.
+ **/
 typedef enum {
 	GMIME_PART_ENCODING_DEFAULT,
 	GMIME_PART_ENCODING_7BIT,
@@ -39,19 +53,29 @@ typedef enum {
 	GMIME_PART_NUM_ENCODINGS
 } GMimePartEncodingType;
 
+
+typedef struct _GMimeReferences GMimeReferences;
+
+/**
+ * GMimeReferences:
+ * @next: Pointer to the next reference.
+ * @msgid: Reference message-id.
+ *
+ * A List of references, as per the References or In-Reply-To header
+ * fields.
+ **/
 struct _GMimeReferences {
-	struct _GMimeReferences *next;
+	GMimeReferences *next;
 	char *msgid;
 };
 
-typedef struct _GMimeReferences GMimeReferences;
 
 #define BASE64_ENCODE_LEN(x) ((size_t) ((x) * 5 / 3) + 4)  /* conservative would be ((x * 4 / 3) + 4) */
 #define QP_ENCODE_LEN(x)     ((size_t) ((x) * 7 / 2) + 4)  /* conservative would be ((x * 3) + 4) */
 
 
 /**
- * GMIME_UUEDECODE_STATE_INIT:
+ * GMIME_UUDECODE_STATE_INIT:
  *
  * Initial state for the g_mime_utils_uudecode_step() function.
  **/
@@ -59,7 +83,7 @@ typedef struct _GMimeReferences GMimeReferences;
 
 
 /**
- * GMIME_UUEDECODE_STATE_BEGIN:
+ * GMIME_UUDECODE_STATE_BEGIN:
  *
  * State for the g_mime_utils_uudecode_step() function, denoting that
  * the 'begin' line has been found.
@@ -68,7 +92,7 @@ typedef struct _GMimeReferences GMimeReferences;
 
 
 /**
- * GMIME_UUEDECODE_STATE_END:
+ * GMIME_UUDECODE_STATE_END:
  *
  * State for the g_mime_utils_uudecode_step() function, denoting that
  * the end of the UU encoded block has been found.
@@ -102,6 +126,9 @@ void   g_mime_utils_unquote_string (char *string);
 gboolean g_mime_utils_text_is_8bit (const unsigned char *text, size_t len);
 GMimePartEncodingType g_mime_utils_best_encoding (const unsigned char *text, size_t len);
 
+/* utility function to convert text in an unknown 8bit/multibyte charset to UTF-8 */
+char *g_mime_utils_decode_8bit (const char *text, size_t len);
+
 /* utilities to (de/en)code headers */
 char *g_mime_utils_header_decode_text (const char *in);
 char *g_mime_utils_header_encode_text (const char *in);
